# -*- coding: utf-8 -*-

from __future__ import unicode_literals

from django.core.mail.backends.base import BaseEmailBackend

try:
    from django.utils.module_loading import import_string
except ImportError:
    from django.utils.module_loading import import_by_path as import_string  # NOQA

from ..apps import EmailHijacker


class EmailBackend(BaseEmailBackend):

    def __init__(self, *args, **kwargs):
        super(EmailBackend, self).__init__(*args, **kwargs)
        self.hijacked = import_string(EmailHijacker.EMAIL_BACKEND)(*args, **kwargs)

    def open(self):
        self.hijacked.open()

    def close(self):
        self.hijacked.close()

    def send_messages(self, email_messages):
        for email in email_messages:
            email.to = (EmailHijacker.EMAIL_ADDRESS,)
            email.bcc = ()
            email.cc = ()
            email.subject = 'HIJACKED: {}'.format(email.subject)
        self.hijacked.send_messages(email_messages)



import unittest
from mock import Mock
from django.core import mail
from django.conf import settings


settings.configure(
    EMAIL_BACKEND="email_hijacker.backends.hijacker.EmailBackend",
    HIJACKER_EMAIL_BACKEND="django.core.mail.backends.locmem.EmailBackend",
    HIJACKER_EMAIL_ADDRESS="hijacker@example.org",
)


class TestEmailBackend(unittest.TestCase):

    def test_open(self):
        backend = mail.get_connection(settings.EMAIL_BACKEND)
        backend.hijacked.open = mock = Mock()
        backend.open()
        self.assertTrue(mock.called)
        self.assertEquals(mock.call_count, 1)

    def test_close(self):
        backend = mail.get_connection(settings.EMAIL_BACKEND)
        backend.hijacked.close = mock = Mock()
        backend.close()
        self.assertTrue(mock.called)
        self.assertEquals(mock.call_count, 1)

    def test_email_message(self):
        mail.EmailMessage("Subject", "Message", from_email=None, to=["to@example.org"], cc=["cc@example.org"], bcc=["bcc@example.org"]).send()
        message = mail.outbox.pop()
        self.assertEqual("HIJACKED: Subject", message.subject)
        self.assertEqual((settings.HIJACKER_EMAIL_ADDRESS,), message.to)
        self.assertEqual((), message.cc)
        self.assertEqual((), message.bcc)
